@@ -37,7 +37,7 @@ class Driver(ahio.abstract_driver.AbstractDriver):
 
     Pins = Enum(
         'Pins',
-        'D0 D1 D2 D3 D4 D5 D6 D7 D8 D9 D10 D11 D12 D13 A1 A2 A3 A4 A5')
+        'D0 D1 D2 D3 D4 D5 D6 D7 D8 D9 D10 D11 D12 D13 A0 A1 A2 A3 A4 A5')
 
     AnalogReferences = Enum('AnalogReferences', 'Default Internal External')
 
