@@ -20,16 +20,37 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-import ahio.abstract_driver
-
+import time
 from enum import Enum
 
+import ahio.abstract_driver
+
 try:
     import snap7
 except Exception:
     ahioDriverInfo.AVAILABLE = False
 
 
+def retry_on_job_pending(func):
+    def f(*args, **kargs):
+        exception = None
+        for _ in range(10):
+            try:
+                return func(*args, **kargs)
+            except snap7.snap7exceptions.Snap7Exception as e:
+                exception = e
+                print(f'Retrying, Exception: {e}')
+                time.sleep(100 / 1000)
+                if 'Job pending' not in str(exception):
+                    raise exception
+        else:
+            if exception:
+                print('retry failed')
+                raise exception
+
+    return f
+
+
 class ahioDriverInfo(ahio.abstract_driver.AbstractahioDriverInfo):
     NAME = 'snap7'
     AVAILABLE = True
@@ -115,6 +136,7 @@ class Driver(ahio.abstract_driver.AbstractDriver):
     def _pin_type(self, pin):
         raise RuntimeError('Hardware does not support querying the pin type')
 
+    @retry_on_job_pending
     def _write(self, pin, value, pwm):
         if pwm:
             raise RuntimeError('Pin does not support PWM')
@@ -127,6 +149,7 @@ class Driver(ahio.abstract_driver.AbstractDriver):
         }.get(value, value)
         self._set_memory(mem, value)
 
+    @retry_on_job_pending
     def _read(self, pin):
         mem = self._parse_port_name(pin)
         value = self._get_memory(mem)
@@ -182,10 +205,12 @@ class Driver(ahio.abstract_driver.AbstractDriver):
         }[s[1]]
         return (area, dtype, start, length)
 
+    @retry_on_job_pending
     def _get_memory(self, mem):
         m = self._client.read_area(mem[0], 0, mem[2], mem[3])
         return mem[1]['get'](m)
 
+    @retry_on_job_pending
     def _set_memory(self, mem, value):
         m = self._client.read_area(mem[0], 0, mem[2], mem[3])
         mem[1]['set'](m, value)
